


Welcome to WETB
===========================================

*- The Wind Energy Toolbox of DTU*

**Quick Start**::

    pip install wetb

Source code repository (and issue tracker):
    https://gitlab.windenergy.dtu.dk/toolbox/WindEnergyToolbox
    
License:
    GPLv3_

.. _GPLv3: https://gitlab.windenergy.dtu.dk/toolbox/WindEnergyToolbox/blob/master/LICENSE.txt


Contents:
    .. toctree::

        fatigue_tools/fatigue
        hawc2/hawc2